@@ -299,8 +299,7 @@ pub fn render(
                     flood::Flood,
                     gaussian_blur::GaussianBlur,
                     image::Image,
-                    light::diffuse_lighting::DiffuseLighting,
-                    light::specular_lighting::SpecularLighting,
+                    light::lighting::Lighting,
                     merge::Merge,
                     morphology::Morphology,
                     offset::Offset,
