@@ -11,11 +11,13 @@ extern crate glib_sys;
 extern crate itertools;
 extern crate libc;
 extern crate nalgebra;
+extern crate num_traits;
 extern crate owning_ref;
 extern crate pango;
 extern crate pango_cairo_sys;
 extern crate pango_sys;
 extern crate pangocairo;
+extern crate rayon;
 extern crate regex;
 
 #[macro_use]
@@ -50,7 +52,6 @@ pub use node::{
     rsvg_node_get_type,
     rsvg_node_is_same,
     rsvg_node_ref,
-    rsvg_node_set_attribute_parse_error,
     rsvg_node_unref,
     rsvg_root_node_cascade,
 };
