@@ -11,7 +11,7 @@ use error::*;
 use float_eq_cairo::ApproxEqCairo;
 use handle::RsvgHandle;
 use iri::IRI;
-use length::{LengthDir, RsvgLength};
+use length::{Length, LengthDir};
 use node::*;
 use parsers;
 use parsers::ParseError;
@@ -51,8 +51,7 @@ impl Parse for MarkerUnits {
                         cow.as_ref().to_string(),
                     ))),
                 ),
-            })
-            .map_err(|_| {
+            }).map_err(|_| {
                 AttributeError::Parse(ParseError::new(
                     "expected \"userSpaceOnUse\" or \"strokeWidth\"",
                 ))
@@ -90,10 +89,10 @@ impl Parse for MarkerOrient {
 
 pub struct NodeMarker {
     units: Cell<MarkerUnits>,
-    ref_x: Cell<RsvgLength>,
-    ref_y: Cell<RsvgLength>,
-    width: Cell<RsvgLength>,
-    height: Cell<RsvgLength>,
+    ref_x: Cell<Length>,
+    ref_y: Cell<Length>,
+    width: Cell<Length>,
+    height: Cell<Length>,
     orient: Cell<MarkerOrient>,
     aspect: Cell<AspectRatio>,
     vbox: Cell<Option<ViewBox>>,
@@ -103,8 +102,8 @@ impl NodeMarker {
     pub fn new() -> NodeMarker {
         NodeMarker {
             units: Cell::new(MarkerUnits::default()),
-            ref_x: Cell::new(RsvgLength::default()),
-            ref_y: Cell::new(RsvgLength::default()),
+            ref_x: Cell::new(Length::default()),
+            ref_y: Cell::new(Length::default()),
             width: Cell::new(NodeMarker::get_default_size(LengthDir::Horizontal)),
             height: Cell::new(NodeMarker::get_default_size(LengthDir::Vertical)),
             orient: Cell::new(MarkerOrient::default()),
@@ -113,9 +112,9 @@ impl NodeMarker {
         }
     }
 
-    fn get_default_size(dir: LengthDir) -> RsvgLength {
+    fn get_default_size(dir: LengthDir) -> Length {
         // per the spec
-        RsvgLength::parse_str("3", dir).unwrap()
+        Length::parse_str("3", dir).unwrap()
     }
 
     fn render(
@@ -218,14 +217,14 @@ impl NodeTrait for NodeMarker {
                     "markerWidth",
                     value,
                     LengthDir::Horizontal,
-                    RsvgLength::check_nonnegative,
+                    Length::check_nonnegative,
                 )?),
 
                 Attribute::MarkerHeight => self.height.set(parse_and_validate(
                     "markerHeight",
                     value,
                     LengthDir::Vertical,
-                    RsvgLength::check_nonnegative,
+                    Length::check_nonnegative,
                 )?),
 
                 Attribute::Orient => self.orient.set(parse("orient", value, ())?),
@@ -1139,30 +1138,30 @@ mod directionality_tests {
 
     #[test]
     fn curve_has_directionality() {
-        let (v1x, v1y, v2x, v2y) = super::get_segment_directionalities(&curve(
-            1.0, 2.0, 3.0, 5.0, 8.0, 13.0, 20.0, 33.0,
-        )).unwrap();
+        let (v1x, v1y, v2x, v2y) =
+            super::get_segment_directionalities(&curve(1.0, 2.0, 3.0, 5.0, 8.0, 13.0, 20.0, 33.0))
+                .unwrap();
         assert_eq!((2.0, 3.0), (v1x, v1y));
         assert_eq!((12.0, 20.0), (v2x, v2y));
     }
 
     #[test]
     fn curves_with_loops_and_coincident_ends_have_directionality() {
-        let (v1x, v1y, v2x, v2y) = super::get_segment_directionalities(&curve(
-            1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 1.0, 2.0,
-        )).unwrap();
+        let (v1x, v1y, v2x, v2y) =
+            super::get_segment_directionalities(&curve(1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 1.0, 2.0))
+                .unwrap();
         assert_eq!((2.0, 2.0), (v1x, v1y));
         assert_eq!((-4.0, -4.0), (v2x, v2y));
 
-        let (v1x, v1y, v2x, v2y) = super::get_segment_directionalities(&curve(
-            1.0, 2.0, 1.0, 2.0, 3.0, 4.0, 1.0, 2.0,
-        )).unwrap();
+        let (v1x, v1y, v2x, v2y) =
+            super::get_segment_directionalities(&curve(1.0, 2.0, 1.0, 2.0, 3.0, 4.0, 1.0, 2.0))
+                .unwrap();
         assert_eq!((2.0, 2.0), (v1x, v1y));
         assert_eq!((-2.0, -2.0), (v2x, v2y));
 
-        let (v1x, v1y, v2x, v2y) = super::get_segment_directionalities(&curve(
-            1.0, 2.0, 3.0, 4.0, 1.0, 2.0, 1.0, 2.0,
-        )).unwrap();
+        let (v1x, v1y, v2x, v2y) =
+            super::get_segment_directionalities(&curve(1.0, 2.0, 3.0, 4.0, 1.0, 2.0, 1.0, 2.0))
+                .unwrap();
         assert_eq!((2.0, 2.0), (v1x, v1y));
         assert_eq!((-2.0, -2.0), (v2x, v2y));
     }
@@ -1177,18 +1176,18 @@ mod directionality_tests {
 
     #[test]
     fn curve_with_123_coincident_has_directionality() {
-        let (v1x, v1y, v2x, v2y) = super::get_segment_directionalities(&curve(
-            0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 20.0, 40.0,
-        )).unwrap();
+        let (v1x, v1y, v2x, v2y) =
+            super::get_segment_directionalities(&curve(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 20.0, 40.0))
+                .unwrap();
         assert_eq!((20.0, 40.0), (v1x, v1y));
         assert_eq!((20.0, 40.0), (v2x, v2y));
     }
 
     #[test]
     fn curve_with_234_coincident_has_directionality() {
-        let (v1x, v1y, v2x, v2y) = super::get_segment_directionalities(&curve(
-            20.0, 40.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
-        )).unwrap();
+        let (v1x, v1y, v2x, v2y) =
+            super::get_segment_directionalities(&curve(20.0, 40.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))
+                .unwrap();
 
         assert_eq!((-20.0, -40.0), (v1x, v1y));
         assert_eq!((-20.0, -40.0), (v2x, v2y));
